@@ -1,15 +1,14 @@
-#include "board.hh"
+#include <gdk/gdkkeysyms.h>
+#include <libosso.h>
 
+#include "board.hh"
 #include "board_image.hh"
 #include "client_image.hh"
 #include "client_image_stream.hh"
 #include "canvas.hh"
 #include "dbus.h"
 #include "sound.h"
-
-#include <gdk/gdkkeysyms.h>
-#include <libosso.h>
-#include <log-functions.h>
+#include "chess_log.h"
 
 #define BOARD_IMAGE_LEFT 24
 #define BOARD_IMAGE_TOP 7
